library(foreign)

## read the data
data <- read.dta("NHAMCS - 2014.dta")

## subset to keep only traffic motor vehicle injuries that affected black men
## (note: for the codes used here, see https://en.wikipedia.org/wiki/List_of_ICD-9_codes_E_and_V_codes:_external_causes_of_injury_and_supplemental_classification)
mvi <- data[data$CAUSE1R >= 8100 & data$CAUSE1R < 8220 & data$SEX == "Male", ]

## calculate the rate of emergency department visits for a motor vehicle injury among black men
## (note: for the denumerator, I used the figure given on p. 32 of the documentation of the NHAMCS,
## which can be found at https://www.cdc.gov/nchs/ahcd/ahcd_questionnaires.htm)
black.visit.rate <- sum(mvi$PATWT[mvi$RACERETH == "Non-Hispanic Black"], na.rm = TRUE)/17779734

## calculate the rate of emergency department visits for a motor vehicle injury among white men
## (note: for the denumerator, I used the figure given on p. 32 of the documentation of the NHAMCS,
## which can be found at https://www.cdc.gov/nchs/ahcd/ahcd_questionnaires.htm)
white.visit.rate <- sum(mvi$PATWT[mvi$RACERETH == "Non-Hispanic White"], na.rm = TRUE)/95587632